OiRA

Help

1. Priprava
2. Vključevanje
3. Identifikacija + Ocena
4. Načrt ukrepov
5. Poročilo
6. Status 0%

# Prilagodite oceno tveganja svoji organizaciji

Da bi prilagodili oceno tveganja svoji organizaciji, boste morda pozvani, da:

- izberite ali preskočite situacije, bistvene ali ne za vašo poslovno dejavnost in označite polje/a, če je smiselno
- prikaži več poslovnih enot, panog, trgovin itd. Ta povezana tveganja se bodo ponovila pri vsakem vnesenem imenu.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More